@@ -12,7 +12,7 @@ use List::Util qw(any);
 use Scalar::Util qw(blessed);
 use Kelp::Context;
 
-our $VERSION = '2.14';
+our $VERSION = '2.15';
 
 # Basic attributes
 attr -host => hostname;
@@ -39,10 +39,8 @@ attr __config => undef;
 
 attr -loaded_modules => sub { {} };
 
-# Data for handling routes
+# Current context data of the application
 attr context => sub { Kelp::Context->new(app => $_[0]) };
-attr req => undef;
-attr res => undef;
 
 # registered application encoder modules
 attr encoder_modules => sub { {} };
@@ -175,6 +173,12 @@ sub build_request
     );
 }
 
+sub req
+{
+    my $self = shift;
+    return $self->context->req(@_);
+}
+
 # Override to use a custom response object
 sub build_response
 {
@@ -183,6 +187,12 @@ sub build_response
     );
 }
 
+sub res
+{
+    my $self = shift;
+    return $self->context->res(@_);
+}
+
 # Override to change what happens before the route is handled
 sub before_dispatch
 {
@@ -618,6 +628,7 @@ contain a reference to the current L<Kelp::Request> instance.
         }
     }
 
+This attribute is a proxy to the same attribute in L</context>.
 
 =head2 res
 
@@ -629,6 +640,8 @@ contain a reference to the current L<Kelp::Response> instance.
         $self->res->json->render( { success => 1 } );
     }
 
+This attribute is a proxy to the same attribute in L</context>.
+
 =head2 context
 
 This holds application's context. Its usage is advanced and only useful for
@@ -660,6 +673,10 @@ A standard constructor. B<Cannot> be called multiple times: see L</new_anon>.
     my $kelp1 = KelpApp->new_anon(config => 'conf1');
     my $kelp2 = KelpApp->new_anon(config => 'conf2');
 
+B<Deprecated>. This only solves the problem in non-controller scenario and will
+completely break with reblessing. It's usually better to treat every Kelp app
+more or less like a singleton.
+
 A constructor that can be called repeatedly. Cannot be mixed with L</new>.
 
 It works by creating a new anonymous class extending the class of your
