@@ -1,6 +1,8 @@
 package MyApp2::Controller::Bar;
 use Kelp::Base 'MyApp2::Controller';
 
+attr last_value => 1;
+
 sub naughty_secret { "I control the Bar" }
 
 sub test_inherit { "OK" }
@@ -21,6 +23,15 @@ sub before_finalize
     $self->res->header('X-Controller' => 'Bar');
 }
 
+sub test_persistence
+{
+    my $self = shift;
+    my $last = $self->last_value;
+    $self->last_value($last + 1);
+
+    return $last;
+}
+
 sub build
 {
     my $self = shift;
